PALM-meteo: palmmeteo_stdplugins.plot Namespace Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Functions
palmmeteo_stdplugins.plot Namespace Reference

## Classes
class | PlotPlugin

## Functions
| import_colormap (qname)
| getfirst (d, *keys)

## Function Documentation

## ◆ getfirst()

palmmeteo_stdplugins.plot.getfirst | ( |  | d,
|  | * | keys
| ) |  |

## ◆ import_colormap()

palmmeteo_stdplugins.plot.import_colormap | ( |  | qname | ) |